<?php

declare(strict_types=1);

namespace Dedi\SyliusSettingsPlugin\Provider;

use Dedi\Contracts\SyliusPluginSettings\SettingsProviderInterface;
use Dedi\Contracts\SyliusPluginSettings\SettingsProviderRegistryInterface;
use InvalidArgumentException;

class Registry implements SettingsProviderRegistryInterface
{
    /**
     * @param array|SettingsProviderInterface[] $settingsProviders
     */
    public function __construct(private array $settingsProviders = [])
    {
    }

    public function getAll(): array
    {
        return $this->settingsProviders;
    }

    public function register(SettingsProviderInterface $settingsProvider): void
    {
        $this->settingsProviders[$settingsProvider->getName()] = $settingsProvider;
    }

    public function get(string $pluginName): SettingsProviderInterface
    {
        if (!array_key_exists($pluginName, $this->settingsProviders)) {
            throw new InvalidArgumentException(sprintf('Settings provider for plugin "%s" not found.', $pluginName));
        }

        return $this->settingsProviders[$pluginName];
    }
}
